[vte] emulation: Deccolm mode switch clears the screen and moves cursor home



commit d45402bd87b6d99d3084eb1ba69ace957a1ac717
Author: Egmont Koblinger <egmont gmail com>
Date:   Sat Jul 26 14:02:56 2014 +0200

    emulation: Deccolm mode switch clears the screen and moves cursor home
    
    https://bugzilla.gnome.org/show_bug.cgi?id=731155#c6

 src/vteseq.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/src/vteseq.c b/src/vteseq.c
index be61f73..9c31c37 100644
--- a/src/vteseq.c
+++ b/src/vteseq.c
@@ -809,13 +809,13 @@ vte_sequence_handler_decset_internal(VteTerminal *terminal,
                                "Leaving application cursor mode.\n");
                break;
        case 3:
                 /* 3: DECCOLM set/reset to 132/80 columns mode */
                 if (terminal->pvt->deccolm_mode) {
                         vte_terminal_emit_resize_window(terminal,
                                                         set ? 132 : 80,
                                                         terminal->pvt->row_count);
-                        /* Request a resize and redraw. */
-                        _vte_invalidate_all(terminal);
+                        _vte_terminal_clear_screen(terminal);
+                        _vte_terminal_home_cursor(terminal);
                 }
                break;
        case 5:
@@ -809,13 +809,13 @@ vte_sequence_handler_decset_internal(VteTerminal *terminal,
                break;
        case 3:
-                /* 3: DECCOLM set/reset to 132/80 columns mode */
+                /* 3: DECCOLM set/reset to 132/80 columns mode, clear screen and cursor home */
                 if (terminal->pvt->deccolm_mode) {
                         vte_terminal_emit_resize_window(terminal,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]